# Colorizer

## En console

Permet de formater la couleur d'un texte.

``colorize [OPTIONS]``

| OPTION | DETAIL |
| :---- | :---- |
| --msg           | message à écrire                                      |
| --fg [COLOR]    | applique la couleur [COLOR] sur le texte              |
| --bg [COLOR]    | applique la couleur [COLOR] sur l'arrière plan        |
| -i              | met le texte en italique                              |
| -b              | met le texte en clignottement                         |
| -s              | raye le texte                                         |
| -u              | souligne le texte                                     |
| -sbg            | surligne le texte avec la couleur de l'arrière plan   |
| -sfg            | surligne le texte avec la couleur du premier plan     |    
| -m              | applique un effet plus prononcé                       |
| -um             | applique un effet plus clair                          |
